FunctionTool class
Function tool
- Implemented types
Constructors
-
FunctionTool({required String name, String? description, Map<
String, dynamic> ? parameters, bool? strict}) -
FunctionTool.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
parameters
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strict → bool?
-
final
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withDescription(
String desc) → FunctionTool - Builder pattern for convenience
-
withParameters(
Map< String, dynamic> params) → FunctionTool -
withStrict(
bool value) → FunctionTool
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited